pub struct CompactFilter { /* private fields */ }Expand description
Bitset filter backed by a scalable Bloom Filter.
This filter operates with the least amount of memory, with a cost
of speed (roughly 60-70% of the speed of the QuickFilter, using
only 25% of the memory).
The backing bloom filter initializes with 1e6 bits by default, with
1e-7 probability of collisions. This is roughly comparable to the
collision rate of the digest filter, so this should be chosen when
memory is critical.